﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web.Http;
using System.Web.Http.Description;
using ToDoWebApi.Models;

namespace ToDoWebApi.Controllers
{
    public class ToDoController : ApiController
    {
        private ToDoContext db = new ToDoContext();

        // GET api/ToDo
        public IQueryable<ToDoTask> GetToDoTask()
        {
            return db.ToDoTasks.Include(c => c.Category);
        }

        // GET api/ToDo/5
        [ResponseType(typeof(ToDoTask))]
        public async Task<IHttpActionResult> GetToDoTask(int id)
        {
            ToDoTask todotask = await (from t in db.ToDoTasks.Include(c => c.Category)
                                       where t.TaskId == id
                                       select t).FirstOrDefaultAsync(); 
            if (todotask == null)
            {
                return NotFound();
            }

            return Ok(todotask);
        }

        // PUT api/ToDo/5
        public async Task<IHttpActionResult> PutToDoTask(int id, ToDoTask todotask)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (id != todotask.TaskId)
            {
                return BadRequest();
            }

            db.Entry(todotask).State = EntityState.Modified;

            try
            {
                await db.SaveChangesAsync();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!ToDoTaskExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return Ok();
        }

        // POST api/ToDo
        [ResponseType(typeof(ToDoTask))]
        public async Task<IHttpActionResult> PostToDoTask(ToDoTask todotask)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            db.ToDoTasks.Add(todotask);
            await db.SaveChangesAsync();

            return CreatedAtRoute("DefaultApi", new { id = todotask.TaskId }, todotask);
        }

        // DELETE api/ToDo/5
        [ResponseType(typeof(ToDoTask))]
        public async Task<IHttpActionResult> DeleteToDoTask(int id)
        {
            ToDoTask todotask = await db.ToDoTasks.FindAsync(id);
            if (todotask == null)
            {
                return NotFound();
            }

            db.ToDoTasks.Remove(todotask);
            await db.SaveChangesAsync();

            return Ok(todotask);
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        private bool ToDoTaskExists(int id)
        {
            return db.ToDoTasks.Count(e => e.TaskId == id) > 0;
        }
    }
}