﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web.Http;
using System.Web.Http.Description;
using BooksAPI.Models;
using BooksAPI.DTOs;

namespace BooksAPI.Controllers
{
    [RoutePrefix("api")]
    public class AuthorsController : ApiController
    {
        private BooksContext db = new BooksContext();

        // GET api/Authors
        public IQueryable<Author> GetAuthors()
        {
            return db.Authors;
        }

        // GET api/Authors/2
        [HttpGet("Authors/{id:int}")]
        [ResponseType(typeof(Author))]
        public async Task<IHttpActionResult> GetAuthor(int id)
        {
            Author author = await db.Authors.FindAsync(id);
            if (author == null)
            {
                return NotFound();
            }

            return Ok(author);
        }

        // GET api/Authors/5/Books
        [HttpGet("Authors/{id:int}/Books")]
        [ResponseType(typeof(IEnumerable<BookDto>))]
        public async Task<IHttpActionResult> GetBooksOfAuthor(int id)
        {
            var books = await (from b in db.Books.Include(b => b.Author)
                        where b.AuthorId == id
                        select new BookDetailDto
                        {
                            Title = b.Title,
                            Genre = b.Genre,
                            PublishDate = b.PublishDate,
                            Price = b.Price,
                            Description = b.Description,
                            Author = b.Author.Name
                        }).ToListAsync();

            if (books == null || books.Count == 0)
            {
                return NotFound();
            }
            return Ok(books);
        }

        [HttpGet("AuthorExists/{id:int}")]
        public bool AuthorExists(int id)
        {
            return db.Authors.Count(e => e.AuthorId == id) > 0;
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

    }
}