using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web;
using System.Web.Http;
using BooksAPI.Models;
using System.Linq.Expressions;
using BooksAPI.DTOs;
using System.Web.Http.Description;
using System.Threading.Tasks;

namespace BooksAPI.Controllers
{
    [RoutePrefix("api")]
    public class BooksController : ApiController
    {
        private BooksContext db = new BooksContext();

        // Typed lambda expression for Select() method. 
        private static readonly Expression<Func<Book, BookDto>> AsBookDto =
            x => new BookDto
            {
                Title = x.Title,
                Author = x.Author.Name,
                Genre = x.Genre
            };

        [HttpGet("books")]
        public IEnumerable<BookDto> GetBooks()
        {
            return db.Books.Include(b => b.Author).Select(AsBookDto);
        }

        [HttpGet("books/{genre}")]
        public IEnumerable<BookDto> GetBooksByGenre(string genre)
        {
            return db.Books.Include(b => b.Author)
                .Where(b => b.Genre.Equals(genre, StringComparison.OrdinalIgnoreCase))
                .Select(AsBookDto);
        }

        //[HttpGet("books/{id:int}")]
        //public BookDto GetBook(int id)
        //{
        //    BookDto book = db.Books.Include(b => b.Author)
        //        .Where(b => b.BookId == id).Select(AsBookDto).FirstOrDefault();
        //    if (book == null)
        //    {
        //        throw new HttpResponseException(
        //            Request.CreateResponse(HttpStatusCode.NotFound));
        //    }
        //    return book;
        //}

        [HttpGet("books/{id:int}")]
        [ResponseType(typeof(Author))]
        public async Task<IHttpActionResult> GetBook(int id)
        {
            BookDto book = await db.Books.Include(b => b.Author)
                .Where(b => b.BookId == id).Select(AsBookDto).FirstOrDefaultAsync();
            if (book == null)
            {
                //throw new HttpResponseException(
                //    Request.CreateResponse(HttpStatusCode.NotFound));
                return NotFound();
            }
            return Ok(book);
        }

        [HttpGet("books/{id:int}/details")]
        public BookDetailDto GetBookDetail(int id)
        {
            var book = (from b in db.Books.Include(b => b.Author)
                        where b.BookId == id
                        select new BookDetailDto
                        {
                            Title = b.Title,
                            Genre = b.Genre,
                            PublishDate = b.PublishDate,
                            Price = b.Price,
                            Description = b.Description,
                            Author = b.Author.Name
                        }).FirstOrDefault();

            if (book == null)
            {
                throw new HttpResponseException(Request.CreateResponse(HttpStatusCode.NotFound));
            }
            return book;
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}