namespace OrdersAPI.Migrations
{
    using OrdersAPI.Models;
    using System;
    using System.Collections.Generic;
    using System.Data.Entity;
    using System.Data.Entity.Migrations;
    using System.Linq;

    internal sealed class Configuration : DbMigrationsConfiguration<OrdersAPI.Models.ShoppingContext>
    {
        public Configuration()
        {
            AutomaticMigrationsEnabled = false;
            ContextKey = "OrdersAPI.Models.ShoppingContext";
        }

        protected override void Seed(OrdersAPI.Models.ShoppingContext context)
        {
            var customers = new List<Customer>()
            {
                new Customer()
                {
                    CustomerId = 1,
                    Name = "Rossi, Mario"
                },

                new Customer()
                {
                    CustomerId = 2,
                    Name = "Verdi, Claudio"
                },

                new Customer()
                {
                    CustomerId = 3,
                    Name = "Bianchi, Roberto"
                }
            };
            context.Customers.AddOrUpdate(c => c.CustomerId, customers.ToArray());

            var addresses = new List<Address>()
            {
                new Address()
                {
                    AddressId = 1,
                    City ="Roma",
                    State = "RM",
                    Country = "Italia",
                    FirstLine = "Via Cuscini, 8",
                    ZipCode = "00100"
                },
                
                new Address()
                {
                    AddressId = 2,
                    City ="Milano",
                    State = "MI",
                    Country = "Italia",
                    FirstLine = "Corso Vittorio Emanuele, 74",
                    ZipCode = "20100"
                },

                new Address()
                {
                    AddressId = 3,
                    City ="Roma",
                    State = "RM",
                    Country = "Italia",
                    FirstLine = "Via Flaminia, 171",
                    ZipCode = "00100"
                }
            };
            context.BilligAddresses.AddOrUpdate(a => a.AddressId, addresses.ToArray());

            var orders = new List<Order>
            {
                new Order()
                {
                    OrderId = 1,
                    AddressId = 1,
                    CustomerId = 1,
                    PurchaseDate = new DateTime(2012,7,21),
                    OrderItems = new List<OrderDetail>
                    {
                        new OrderDetail()
                        {
                            OrderDetailId = 1,
                            Name = "Biscotti",
                            Ammount = 8,
                            Price = 12.75M
                        },
                        
                        new OrderDetail()
                        {
                            OrderDetailId = 2,
                            Name = "Nutella",
                            Ammount = 2,
                            Price = 4.55M
                        }
                    }
                },

                new Order()
                {
                    OrderId = 2,
                    AddressId = 1,
                    CustomerId = 1,
                    PurchaseDate = new DateTime(2013,9,21),
                    OrderItems = new List<OrderDetail>
                    {
                        new OrderDetail()
                        {
                            OrderDetailId = 3,
                            Name = "Pesche",
                            Ammount = 20,
                            Price = 0.75M
                        },
                        
                        new OrderDetail()
                        {
                            OrderDetailId = 4,
                            Name = "Limoni",
                            Ammount = 5,
                            Price = 0.55M
                        }
                    }
                },

                new Order()
                {
                    OrderId = 3,
                    AddressId = 2,
                    CustomerId = 2,
                    PurchaseDate = new DateTime(2013,6,11),
                    OrderItems = new List<OrderDetail>
                    {
                        new OrderDetail()
                        {
                            OrderDetailId = 5,
                            Name = "Farina",
                            Ammount = 2,
                            Price = 1.25M
                        },
                        
                        new OrderDetail()
                        {
                            OrderDetailId = 6,
                            Name = "Uova",
                            Ammount = 12,
                            Price = 0.75M
                        }
                    }
                },

                new Order()
                {
                    OrderId = 4,
                    AddressId = 3,
                    CustomerId = 3,
                    PurchaseDate = new DateTime(2013,9,10),
                    OrderItems = new List<OrderDetail>
                    {
                        new OrderDetail()
                        {
                            OrderDetailId = 7,
                            Name = "Confettura di fragole",
                            Ammount = 2,
                            Price = 3.85M
                        }
                    }
                }
            };
            context.Orders.AddOrUpdate(o => o.OrderId, orders.ToArray());
        }
    }
}